atomate.feff.firetasks package — atomate 0.3 documentation

# atomate.feff.firetasks package

## Submodules

## atomate.feff.firetasks.parse_outputs module

class `atomate.feff.firetasks.parse_outputs.` `SpectrumToDbTask`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Parse the output of absorption/core-loss spectrum calculations(xmu.dat, eels.dat) and insert it into the database.

  Required_params:
    absorbing_atom (str): absorbing atom symbol structure (Structure): input structure spectrum_type (str): XANES, EXAFS, ELNES, EXELFS output_file (str): the output file name. xmu.dat or eels.dat
  Optional_params:

    input_file (str): path to the feff input file. calc_dir (str): path to dir (on current filesystem) that contains FEFF output files.

    > Default: use current working directory.

    calc_loc (str OR bool): if True will set most recent calc_loc. If str search for the most
      recent calc_loc with the matching name

    db_file (str): path to the db file. edge (str): absorption edge metadata (dict): meta data

  `optional_params` = [u'input_file', u'calc_dir', u'calc_loc', u'db_file', u'edge', u'metadata']
  `required_params` = [u'absorbing_atom', u'structure', u'spectrum_type', u'output_file']
  `run_task`(fw_spec)

## atomate.feff.firetasks.run_calc module

class `atomate.feff.firetasks.run_calc.` `RunFeffDirect`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Run FEFF directly (no custodian). Supports env_chk.

  Required params:
    feff_cmd (str): the name of the full executable for running FEFF.
  `required_params` = [u'feff_cmd']
  `run_task`(fw_spec)

## atomate.feff.firetasks.write_inputs module

class `atomate.feff.firetasks.write_inputs.` `WriteFeffFromIOSet`(*args, **kwargs)

  Bases: `fireworks.core.firework.FireTaskBase`

  Generate FEFF input(feff.inp) from the given inputset object or inputset name

  Required_params:
    absorbing_atom (str): absorbing atom symbol structure (Structure): input structure
  Optional_params:
    radius (float): cluster radius in angstroms other_params (dict)
  `optional_params` = [u'radius', u'other_params']
  `required_params` = [u'absorbing_atom', u'structure', u'feff_input_set']
  `run_task`(fw_spec)

## Module contents